==> haskell-ghc-lib-parser-ex-9.0.0.4-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-lib-parser-ex
version:              9.0.0.4
visibility:           public
id:                   ghc-lib-parser-ex-9.0.0.4-JF4VN3E1ZW7J77cHQuVfyM
key:                  ghc-lib-parser-ex-9.0.0.4-JF4VN3E1ZW7J77cHQuVfyM
license:              BSD-3-Clause
copyright:            Copyright © 2020, Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  6c529436fc6c4b47d91841016b039674
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Config
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable
    Language.Haskell.GhclibParserEx.Outputable
    Language.Haskell.GhclibParserEx.Parse

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-ex-9.0.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-ex-9.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.0.0.4-JF4VN3E1ZW7J77cHQuVfyM
include-dirs:
    /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-ex-9.0.0.4/include

depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1 ghc-9.0.2
    ghc-boot-9.0.2 ghc-boot-th-9.0.2
    uniplate-1.6.13-Ixt7G7Wy1brGt6f3UK6gxf

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-lib-parser-ex-9.0.0.4-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-lib-parser-ex
version:              9.0.0.4
visibility:           public
id:                   ghc-lib-parser-ex-9.0.0.4-4FYIZAVT3blABM0TuMZD7m
key:                  ghc-lib-parser-ex-9.0.0.4-4FYIZAVT3blABM0TuMZD7m
license:              BSD-3-Clause
copyright:            Copyright © 2020, Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  2e8e836f2863378c1388f2e003c995f6
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Config
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable
    Language.Haskell.GhclibParserEx.Outputable
    Language.Haskell.GhclibParserEx.Parse

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-ex-9.0.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-ex-9.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.0.0.4-4FYIZAVT3blABM0TuMZD7m
include-dirs:
    /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-ex-9.0.0.4/include

depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1 ghc-9.0.2
    ghc-boot-9.0.2 ghc-boot-th-9.0.2
    uniplate-1.6.13-FaNu6p3HDjeLi97b1NYCVt

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
